/*
 * Copyright (c) 2001 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.html;

import org.w3c.dom.Document;

/**
 * Generic embedded object.In principle, all properties on the object element 
 * are read-write but in some environments some properties may be read-only 
 * once the underlying object is instantiated. See the OBJECT element 
 * definition in .
 * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-2-HTML-20011210'>Document Object Model (DOM) Level 2 HTML Specification</a>.
 */
public interface HTMLObjectElement extends HTMLElement {
    /**
     * Applet class file. See the <code>code</code> attribute for 
     * HTMLAppletElement. 
     */
    public String getCode();
    /**
     * Applet class file. See the <code>code</code> attribute for 
     * HTMLAppletElement. 
     */
    public void setCode(String code);

    /**
     * Aligns this object (vertically or horizontally) with respect to its 
     * surrounding text. See the align attribute definition in HTML 4.0. 
     * This attribute is deprecated in HTML 4.0.
     */
    public String getAlign();
    /**
     * Aligns this object (vertically or horizontally) with respect to its 
     * surrounding text. See the align attribute definition in HTML 4.0. 
     * This attribute is deprecated in HTML 4.0.
     */
    public void setAlign(String align);

    /**
     * Space-separated list of archives. See the archive attribute definition 
     * in HTML 4.0.
     */
    public String getArchive();
    /**
     * Space-separated list of archives. See the archive attribute definition 
     * in HTML 4.0.
     */
    public void setArchive(String archive);

    /**
     * Width of border around the object. See the border attribute definition 
     * in HTML 4.0. This attribute is deprecated in HTML 4.0.
     */
    public String getBorder();
    /**
     * Width of border around the object. See the border attribute definition 
     * in HTML 4.0. This attribute is deprecated in HTML 4.0.
     */
    public void setBorder(String border);

    /**
     * Base URI  for <code>classid</code>, <code>data</code>, and 
     * <code>archive</code> attributes. See the codebase attribute definition
     *  in HTML 4.0.
     */
    public String getCodeBase();
    /**
     * Base URI  for <code>classid</code>, <code>data</code>, and 
     * <code>archive</code> attributes. See the codebase attribute definition
     *  in HTML 4.0.
     */
    public void setCodeBase(String codeBase);

    /**
     * Content type for data downloaded via <code>classid</code> attribute. 
     * See the codetype attribute definition in HTML 4.0.
     */
    public String getCodeType();
    /**
     * Content type for data downloaded via <code>classid</code> attribute. 
     * See the codetype attribute definition in HTML 4.0.
     */
    public void setCodeType(String codeType);

    /**
     * A URI  specifying the location of the object's data. See the data 
     * attribute definition in HTML 4.0.
     */
    public String getData();
    /**
     * A URI  specifying the location of the object's data. See the data 
     * attribute definition in HTML 4.0.
     */
    public void setData(String data);

    /**
     * Declare (for future reference), but do not instantiate, this object. 
     * See the declare attribute definition in HTML 4.0.
     */
    public boolean getDeclare();
    /**
     * Declare (for future reference), but do not instantiate, this object. 
     * See the declare attribute definition in HTML 4.0.
     */
    public void setDeclare(boolean declare);

    /**
     * Override height. See the height attribute definition in HTML 4.0.
     */
    public String getHeight();
    /**
     * Override height. See the height attribute definition in HTML 4.0.
     */
    public void setHeight(String height);

    /**
     * Horizontal space to the left and right of this image, applet, or 
     * object. See the hspace attribute definition in HTML 4.0. This 
     * attribute is deprecated in HTML 4.0.
     */
    public String getHspace();
    /**
     * Horizontal space to the left and right of this image, applet, or 
     * object. See the hspace attribute definition in HTML 4.0. This 
     * attribute is deprecated in HTML 4.0.
     */
    public void setHspace(String hspace);

    /**
     * Form control or object name when submitted with a form. See the name 
     * attribute definition in HTML 4.0.
     */
    public String getName();
    /**
     * Form control or object name when submitted with a form. See the name 
     * attribute definition in HTML 4.0.
     */
    public void setName(String name);

    /**
     * Message to render while loading the object. See the standby attribute 
     * definition in HTML 4.0.
     */
    public String getStandby();
    /**
     * Message to render while loading the object. See the standby attribute 
     * definition in HTML 4.0.
     */
    public void setStandby(String standby);

    /**
     * Index that represents the element's position in the tabbing order. See 
     * the tabindex attribute definition in HTML 4.0.
     */
    public int getTabIndex();
    /**
     * Index that represents the element's position in the tabbing order. See 
     * the tabindex attribute definition in HTML 4.0.
     */
    public void setTabIndex(int tabIndex);

    /**
     * Content type for data downloaded via <code>data</code> attribute. See 
     * the type attribute definition in HTML 4.0.
     */
    public String getType();
    /**
     * Content type for data downloaded via <code>data</code> attribute. See 
     * the type attribute definition in HTML 4.0.
     */
    public void setType(String type);

    /**
     * Use client-side image map. See the usemap attribute definition in HTML 
     * 4.0.
     */
    public String getUseMap();
    /**
     * Use client-side image map. See the usemap attribute definition in HTML 
     * 4.0.
     */
    public void setUseMap(String useMap);

    /**
     * Vertical space above and below this image, applet, or object. See the 
     * vspace attribute definition in HTML 4.0. This attribute is deprecated 
     * in HTML 4.0.
     */
    public String getVspace();
    /**
     * Vertical space above and below this image, applet, or object. See the 
     * vspace attribute definition in HTML 4.0. This attribute is deprecated 
     * in HTML 4.0.
     */
    public void setVspace(String vspace);

    /**
     * Override width. See the width attribute definition in HTML 4.0.
     */
    public String getWidth();
    /**
     * Override width. See the width attribute definition in HTML 4.0.
     */
    public void setWidth(String width);

    /**
     * The document this object contains, if there is any and it is available, 
     * or <code>null</code> otherwise.
     * @since DOM Level 2
     */
    public Document getContentDocument();

}
